# Authors and Contributors

**Main authors** are persons whose contributions significantly shaped
the state of the software at some point in time.

**Additional contributors** are persons who are not main authors,
but contributed non-trivially to this project,
e.g. by providing smaller fixes and enhancements to the code and/or documentation.

Of course, this is just a rough overview and categorization.
For a more complete overview of all contributors and contributions,
please inspect the git history of this repository.

## Main Authors

- Anton Pirogov (
    [E-Mail](mailto:a.pirogov@fz-juelich.de),
    [ORCID](https://orcid.org/0000-0002-5077-7497)
  ): original author

## Additional Contributors

<!--
- Name (E-mail, ORCID):
Summary of contribution
-->

... maybe **[you](https://materials-data-science-and-informatics.github.io/metador-core/main/contributing)**?
